//
//  DropDownMenu.m
//  QQSafetyCenter
//
//  Created by 曾诗亮 on 2017/1/13.
//  Copyright © 2017年 zsl. All rights reserved.
//

#import "DropDownMenu.h"

@interface DropDownMenu ()

@property (strong, nonatomic) UIView *dropDownView;
@property (strong, nonatomic) UIControl *control;

@property (strong, nonatomic) UIView *leftView;
@property (strong, nonatomic) UIImageView *leftIV;
@property (strong, nonatomic) UILabel *leftLb;

@property (strong, nonatomic) UIView *rightView;
@property (strong, nonatomic) UIImageView *rightIV;
@property (strong, nonatomic) UILabel *rightLB;

@end

#define kWidth  [UIScreen mainScreen].bounds.size.width
#define kHeight [UIScreen mainScreen].bounds.size.height

#define kDuration 0.5


@implementation DropDownMenu
{
    NSArray *_images;
    NSArray *_titles;
    
    UIWindow *_window;
    
    BOOL _isMenu;
}

- (instancetype)initWithImages:(NSArray *)images titles:(NSArray *)titles
{
    if (self = [super init]) {
        _images = images;
        _titles = titles;
        
        _window = [UIApplication sharedApplication].keyWindow;
        
        _isMenu = NO;
    }
    return self;
}

- (void)showMenu
{
    if (!_isMenu) {
        [UIView animateWithDuration:kDuration animations:^{
            self.control.alpha = 0.3f;
            self.dropDownView.alpha = 1.0f;
        }];
        
        [self leftView];
        [self rightView];
        
        [self leftLb];
        [self rightLB];
        
        _isMenu = YES;
        
    }else {
       [self dismissControl];
    }
}

- (void)hideMenu
{
    [self dismissControl];
}

- (void)showTitle:(ShowTitle)block
{
    self.showtitle = block;
}

#pragma mark - 懒加载
- (UIView *)dropDownView
{
    if (!_dropDownView) {
        _dropDownView = [[UIView alloc] initWithFrame:CGRectMake(0, 64, kWidth, 64)];
        _dropDownView.backgroundColor = [UIColor blackColor];
        _dropDownView.alpha = 0.0f;
        [_window addSubview:self.dropDownView];
    }
    return _dropDownView;
}

- (UIControl *)control
{
    if (!_control) {
        _control = [UIControl new];
        _control.backgroundColor = [UIColor blackColor];
        _control.alpha = 0.0f;
        [_window addSubview:_control];
        [_control mas_makeConstraints:^(MASConstraintMaker *make) {
            make.top.mas_equalTo(64);
            make.left.bottom.right.mas_equalTo(0);
        }];
        [_control addTarget:self action:@selector(clickControl:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _control;
}

- (void)clickControl:(UIControl *)sender
{
    [self dismissControl];
}

- (void)dismissControl
{
    _isMenu = NO;
    
    [UIView animateWithDuration:kDuration animations:^{
        self.dropDownView.alpha = 0.0f;
        self.control.alpha = 0.0f;
    }];
}

- (UIView *)leftView
{
    if (!_leftView) {
        _leftView = [UIView new];
//        _leftView.backgroundColor = [UIColor redColor];
        [self.dropDownView addSubview:_leftView];
        [_leftView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.top.left.bottom.mas_equalTo(0);
            make.width.mas_equalTo(kWidth/2);
        }];
        
        UITapGestureRecognizer *tap = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(clickLeftView:)];
        [_leftView addGestureRecognizer:tap];
    }
    return _leftView;
}

- (void)clickLeftView:(UITapGestureRecognizer *)tap
{
    [self dismissControl];
    
    self.showtitle(_titles.firstObject);
}

- (UIImageView *)leftIV
{
    if (!_leftIV) {
        _leftIV = [UIImageView new];
        _leftIV.image = [UIImage imageNamed:_images.firstObject];
        [self.leftView addSubview:_leftIV];
        [_leftIV mas_makeConstraints:^(MASConstraintMaker *make) {
            make.centerX.mas_equalTo(0);
            make.top.mas_equalTo(5);
            make.size.mas_equalTo(CGSizeMake(30, 30));
        }];
    }
    return _leftIV;
}

- (UILabel *)leftLb
{
    if (!_leftLb) {
        _leftLb = [UILabel new];
//        _leftLb.backgroundColor = [UIColor redColor];
        _leftLb.textColor = [UIColor whiteColor];
        _leftLb.text = _titles.firstObject;
        [self.leftView addSubview:_leftLb];
        [_leftLb mas_makeConstraints:^(MASConstraintMaker *make) {
            make.centerX.mas_equalTo(self.leftIV);
            make.top.mas_equalTo(self.leftIV.mas_bottom).mas_equalTo(5);
        }];
    }
    return _leftLb;
}

- (UIView *)rightView
{
    if (!_rightView) {
        _rightView = [UIView new];
//        _rightView.backgroundColor = [UIColor greenColor];
        [self.dropDownView addSubview:_rightView];
        [_rightView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.top.right.bottom.mas_equalTo(0);
            make.width.mas_equalTo(kWidth/2);
        }];
        
        UITapGestureRecognizer *tap = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(clickRightView:)];
        [_rightView addGestureRecognizer:tap];
    }
    return _rightView;
}

- (void)clickRightView:(UITapGestureRecognizer *)tap
{
    [self dismissControl];
    
    self.showtitle(_titles.lastObject);
}

- (UIImageView *)rightIV
{
    if (!_rightIV) {
        _rightIV = [UIImageView new];
        _rightIV.image = [UIImage imageNamed:_images.lastObject];
        [self.rightView addSubview:_rightIV];
        [_rightIV mas_makeConstraints:^(MASConstraintMaker *make) {
            make.centerX.mas_equalTo(0);
            make.top.mas_equalTo(5);
            make.size.mas_equalTo(CGSizeMake(30, 30));
        }];
    }
    return _rightIV;
}

- (UILabel *)rightLB
{
    if (!_rightLB) {
        _rightLB = [UILabel new];
        _rightLB.textColor = [UIColor whiteColor];
        _rightLB.text = _titles.lastObject;
        [self.rightView addSubview:_rightLB];
        [_rightLB mas_makeConstraints:^(MASConstraintMaker *make) {
            make.centerX.mas_equalTo(self.rightIV);
            make.top.mas_equalTo(self.rightIV.mas_bottom).mas_equalTo(5);
        }];
    }
    return _rightLB;
}

@end
